Translators — Jinja Documentation

# Jinja

## Translators

Jinja translates the template sourcecode into executable python code behind the secenes. This is done by the python translator which is currently the only shipped translator. Because the interface isn't stable it's also not recommended yet to write other translators. However for one of the next Jinja versions a JavaScript translator is planned which allows you to translate Jinja templates into executable JavaScript code.